
const electron         = require('electron')
const app              = electron.app
const BrowserWindow    = electron.BrowserWindow
const {Menu, MenuItem} = electron

const width     = 16 * 80
const height    =  9 * 80
const USE_TOOLS = false
const version   = "0.8"

// prevent garbage collection
let mainWindow

function createWindow () {

  mainWindow = new BrowserWindow({
    "width" : width,
    "height": height,
    "frame" : true,
    "icon"  : __dirname + "/../icons/logo.large.alt.png",
    "web-preferences" : {
        "web-security"            : false,
        "overlay-fullscreen-video": true,
        "webaudio"                : true,
        "webgl"                   : true,
        "text-areas-are-resizable": true,
    }
  })

  // load site
  mainWindow.loadURL(`file://${__dirname}/../site/index.html`)

  // Open the DevTools.
  USE_TOOLS && mainWindow.webContents.openDevTools()

  // Emitted when the window is closed.
  mainWindow.on('closed', function () {
    mainWindow = null
  })

  createMenus();

}

app.on('ready', createWindow)

app.on('window-all-closed', function () {
  // if (process.platform !== 'darwin') {
    app.quit()
  // }
})

app.on('activate', function () {
  if (mainWindow === null) {
    createWindow()
  }
})


function createMenus() {
  // In this file you can include the rest of your app's specific main process
  // code. You can also put them in separate files and require them here.
  const template = [
    {
      label: "help",
      role: 'help',
      submenu: [
        {
          label: 'beta v' + version,
          enabled: false
        },
        {
          role: 'separator'
        },
        {
          label: 'help',
          click() { electron.shell.openExternal('https://www.chalkysticks.com/tv'); }
        },
        {
          label: 'send feedback',
          click() { electron.shell.openExternal('mailto:feedback@chalkysticks.com'); }
        },
      ]
    }
  ];

  if (process.platform === 'darwin') {
    const name = "ChalkySticks TV";

    template.unshift({
      label: name,
      submenu: [
        {
          role: 'about'
        },
        {
          type: 'separator'
        },
        {
          role: 'hide'
        },
        {
          role: 'hideothers'
        },
        {
          role: 'unhide'
        },
        {
          type: 'separator'
        },
        {
          role: 'quit'
        },
      ]
    });
  }

  template.push({
    label: "beta v" + version,
    submenu: [
    ]
  });

  const menu = Menu.buildFromTemplate(template);
  Menu.setApplicationMenu(menu);

}